MethodChannelFlutterDes class

An implementation of FlutterDesPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFlutterDes()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Uint8List data, String key, {String iv = _iv}) → Future<String?>
override
decryptFromBase64(String base64, String key, {String iv = _iv}) → Future<String?>
override
decryptFromHex(String? hex, String key, {String iv = _iv}) → Future<String?>
override
encrypt(String string, String key, {String iv = _iv}) → Future<Uint8List?>
override
encryptToBase64(String string, String key, {String iv = _iv}) → Future<String>
override
encryptToHex(String string, String key, {String iv = _iv}) → Future<String?>
override
getPlatformVersion() → Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited