FlutterDesPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterDesPlatform
Implementers

Constructors

FlutterDesPlatform()
Constructs a FlutterDesPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Uint8List data, String key, {String iv = _iv}) → Future<String?>
decryptFromBase64(String base64, String key, {String iv = _iv}) → Future<String?>
decryptFromHex(String? hex, String key, {String iv = _iv}) → Future<String?>
encrypt(String string, String key, {String iv = _iv}) → Future<Uint8List?>
encryptToBase64(String string, String key, {String iv = _iv}) → Future<String>
encryptToHex(String string, String key, {String iv = _iv}) → Future<String?>
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterDesPlatform
The default instance of FlutterDesPlatform to use.
getter/setter pair